view

package
v0.0.0-...-ff98b99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: Apache-2.0 Imports: 34 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewAccess

func NewAccess(ctx context.Context, baseViewArgs *minkapi.ViewArgs) (va minkapi.ViewAccess, err error)

NewAccess creates a new ViewAccess instance with a default base minkapi.View using the provided context and ViewArgs.

func NewBase

func NewBase(args *minkapi.ViewArgs) (minkapi.View, error)

NewBase creates and initializes a new "base" instance of View, configured with the provided logger and ViewArgs.

func NewSandbox

func NewSandbox(delegateView minkapi.View, args *minkapi.ViewArgs) (minkapi.View, error)

NewSandbox returns a "sandbox" (private) view which holds changes made via its facade into its private store independent of the base view, otherwise delegating to the delegate View.

Types

This section is empty.

Jump to